@@ -17,30 +17,45 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {}{[@var{X},@var{Y}] =}op_fwd(@var{lon},@var{lat},@var{params})
+## @deftypefn {Function file}{[@var{X},@var{Y}] =}op_fwd(@var{lon},@var{lat},@var{params})
+##
+## @cindex Performs forward projection step.
 ##
 ## This function projects geodetic coordinates into cartesian projected
 ## coordinates in the defined cartographic projection using the PROJ function
 ## proj_trans_generic().
 ##
-## @var{lon} contains the geodetic longitude.
-## @var{lat} contains the geodetic latitude.
+## INPUT ARGUMENTS:
+##
+## @itemize @bullet
+## @item
+## @var{lon} contains by default the geodetic longitude.
+## @item
+## @var{lat} contains by default the geodetic latitude.
+## @item
 ## @var{params} is a text string containing the projection parameters in PROJ
-## format (ONLY format '+' style, see https://proj.org/usage/index.html).
+## format (ONLY format '+' style is allowed, in any other case results are not
+## guaranteed).
+## @end itemize
 ##
-## @var{lon} or @var{lat} can be scalars, vectors or 2D matrices.
-## Angular units are by default radians, although other units can be specified
-## in @var{params}, so @var{lon} and @var{lat} must be congruent with
-## @var{params}
+## OUTPUT ARGUMENTS:
 ##
-## @var{X} contains the X projected coordinates.
-## @var{Y} contains the Y projected coordinates.
+## @itemize @bullet
+## @item
+## @var{X} contains by default the X projected coordinates.
+## @item
+## @var{Y} contains by default the Y projected coordinates.
+## @end itemize
 ##
-## If a projection error occurs, the resultant coordinates for the affected
+## @var{lon} or @var{lat} can be scalars, vectors or 2D matrices. @var{X} and
+## @var{X} will be according to the higher dimension input argument.
+## Angular units are by default radians and linear meters, although other can be
+## specified in @var{params}, so @var{lon} and @var{lat} must be congruent with
+## @var{params}. The same applies to the coordinate order at input and output.
+##
+## If a projection error occurs the resultant coordinates for the affected
 ## points have both Inf value and a warning message is emitted (one for each
 ## erroneous point).
-## Linear units are by default meters, although other can be specified in
-## @var{params}, so @var{X} and @var{Y} will be congruent with @var{params}.
 ##
 ## @seealso{op_inv, op_transform}
 ## @end deftypefn
@@ -143,7 +158,7 @@ b = reshape(b,rowWork*colWork,1);
 
 
 %!test
-%!  [x,y]=op_fwd(-6*pi/180,43*pi/180,'+proj=utm +lon_0=3w +ellps=GRS80');
+%!  [x,y]=op_fwd(-6*pi/180,43*pi/180,'+proj=utm +zone=30 +ellps=GRS80');
 %!  assert(x,255466.98,1e-2)
 %!  assert(y,4765182.93,1e-2)
 %!error(op_fwd)
@@ -151,7 +166,7 @@ b = reshape(b,rowWork*colWork,1);
 %!error(op_fwd('string',2,3))
 %!error(op_fwd(1,'string',3))
 %!error(op_fwd(1,2,3))
-%!error(op_fwd([1 2 3],[2 2;3 3],'+proj=utm +lon_0=3w +ellps=GRS80'))
+%!error(op_fwd([1 2 3],[2 2;3 3],'+proj=utm +zone=30 +ellps=GRS80'))
 
 
 
