@@ -1,5 +1,5 @@
 /* -*- coding: utf-8 -*- */
-/* Copyright (C) 2009-2020  José Luis García Pallero, <jgpallero@gmail.com>
+/* Copyright (C) 2009-2022  José Luis García Pallero, <jgpallero@gmail.com>
  *
  * This file is part of OctPROJ.
  *
@@ -21,27 +21,43 @@
 /******************************************************************************/
 #define HELPTEXT "\
 -*- texinfo -*-\n\
-@deftypefn {}{[@var{X},@var{Y},@var{Z}] =}_op_geod2geoc(@var{lon},@var{lat},@var{h},@var{a},@var{e2})\n\
+@deftypefn {Function file}{[@var{X},@var{Y},@var{Z}] =}_op_geod2geoc(@var{lon},@var{lat},@var{h},@var{a},@var{e2})\n\
 \n\
 @cindex Geodetic to geocentric coordinates.\n\
 \n\
 This function converts geodetic coordinates into cartesian tridimensional\n\
 geocentric coordinates.\n\
 \n\
+INPUT ARGUMENTS:\n\
+\n\
+@itemize @bullet\n\
+@item\n\
 @var{lon} is a column vector containing the geodetic longitude, in radians.\n\
+@item\n\
 @var{lat} is a column vector containing the geodetic latitude, in radians.\n\
+@item\n\
 @var{h} is a column vector containing the ellipsoidal height, in meters.\n\
+@item\n\
 @var{a} is a scalar containing the semi-major axis of the ellipsoid, in \
 meters.\n\
+@item\n\
 @var{e2} is a scalar containing the squared first eccentricity of the \
 ellipsoid.\n\
+@end itemize\n\
+\n\
+OUTPUT ARGUMENTS:\n\
+\n\
+@itemize @bullet\n\
+@item\n\
+@var{X} is a column vector containing the X geocentric coordinate, in meters.\n\
+@item\n\
+@var{Y} is a column vector containing the Y geocentric coordinate, in meters.\n\
+@item\n\
+@var{Z} is a column vector containing the Z geocentric coordinate, in meters.\n\
+@end itemize\n\
 \n\
 The coordinate vectors @var{lon}, @var{lat} and @var{h} must be all scalars\n\
 or all column vectors (of the same size).\n\
-\n\
-@var{X} is a column vector containing the X geocentric coordinate, in meters.\n\
-@var{Y} is a column vector containing the Y geocentric coordinate, in meters.\n\
-@var{Z} is a column vector containing the Z geocentric coordinate, in meters.\n\
 @seealso{_op_geoc2geod}\n\
 @end deftypefn"
 /******************************************************************************/
@@ -69,7 +85,7 @@ DEFUN_DLD(_op_geod2geoc,args,,HELPTEXT)
                 "Incorrect number of input arguments\n\t"
                 "See help _op_geod2geoc");
         //error message
-        error(errorText);
+        error("%s",errorText);
     }
     else
     {
