@@ -1,5 +1,5 @@
 /* -*- coding: utf-8 -*- */
-/* Copyright (C) 2009, 2011  José Luis García Pallero, <jgpallero@gmail.com>
+/* Copyright (C) 2009-2022  José Luis García Pallero, <jgpallero@gmail.com>
  *
  * This file is part of OctPROJ.
  *
@@ -21,7 +21,7 @@
 /******************************************************************************/
 #define HELPTEXT "\
 -*- texinfo -*-\n\
-@deftypefn {}{[@var{lon},@var{lat}] =}_op_inv(@var{X},@var{Y},@var{params})\n\
+@deftypefn {Function file}{[@var{lon},@var{lat}] =}_op_inv(@var{X},@var{Y},@var{params})\n\
 \n\
 @cindex Performs inverse projection step.\n\
 \n\
@@ -29,24 +29,38 @@ This function unprojects cartesian projected coordinates (in a defined\n\
 cartographic projection) into geodetic coordinates using the PROJ function \
 proj_trans_generic().\n\
 \n\
-@var{X} is a column vector containing the X projected coordinates.\n\
-@var{Y} is a column vector containing the Y projected coordinates.\n\
+INPUT ARGUMENTS:\n\
+\n\
+@itemize @bullet\n\
+@item\n\
+@var{X} is a column vector containing by default the X projected coordinates.\n\
+@item\n\
+@var{Y} is a column vector containing by default the Y projected coordinates.\n\
+@item\n\
 @var{params} is a text string containing the projection parameters in PROJ \n\
-format (ONLY format '+' style).\n\
+format (ONLY format '+' style is allowed, in any other case results are not \
+guaranteed).\n\
+@end itemize\n\
+\n\
+OUTPUT ARGUMENTS:\n\
+\n\
+@itemize @bullet\n\
+@item\n\
+@var{X} is a column vector containing by default the X projected coordinates.\n\
+@item\n\
+@var{Y} is a column vector containing by default the Y projected coordinates.\n\
+@end itemize\n\
 \n\
 The coordinate vectors @var{X} and @var{Y} must be both scalars or both\n\
-column vectors (of the same size).\n\
-Linear units are by default meters, although other can be specified in \n\
-@var{params}, so @var{X} and @var{Y} must be congruent with @var{params} \n\
+column vectors (of the same size). @var{lon} and @var{lat} will be according\n\
+to the input dimensions.\n\
+Angular units are by default radians and linear meters, although other can be\n\
+specified in @var{params}, so @var{X} and @var{Y} must be congruent with\n\
+@var{params}. The same applies to the coordinate order at input and output.\n\
 \n\
-@var{lon} is a column vector containing the geodetic longitude.\n\
-@var{lat} is a column vector containing the geodetic latitude.\n\
-\n\
-If a projection error occurs, the resultant coordinates for the affected\n\
+If a projection error occurs the resultant coordinates for the affected\n\
 points have both Inf value and a warning message is emitted (one for each\n\
 erroneous point).\n\
-Angular units are by default radians, although other can be specified in \n\
-@var{params}, so @var{lon} and @var{lat} will be congruent with @var{params} \n\
 @seealso{_op_fwd, _op_transform}\n\
 @end deftypefn"
 /******************************************************************************/
@@ -74,7 +88,7 @@ DEFUN_DLD(_op_inv,args,,HELPTEXT)
                 "Incorrect number of input arguments\n\t"
                 "See help _op_inv");
         //error message
-        error(errorText);
+        error("%s",errorText);
     }
     else
     {
@@ -120,7 +134,7 @@ DEFUN_DLD(_op_inv,args,,HELPTEXT)
             if(projectionError>-1)
             {
                 //warning message
-                warning(errorText);
+                warning("%s",errorText);
                 //positions of projection errors
                 for(i=0;i<nElem;i++)
                 {
@@ -130,13 +144,16 @@ DEFUN_DLD(_op_inv,args,,HELPTEXT)
                         //error text
                         warning("Projection error in point %zu "
                                 "(index starts at 1)",i+1);
+                        //assign Inf values
+                        lon[i] = INFINITY;
+                        lat[i] = INFINITY;
                     }
                 }
             }
             else
             {
                 //error message
-                error(errorText);
+                error("%s",errorText);
                 //exit
                 return outputList;
             }
