@@ -38,6 +38,8 @@ int proj_fwd(double* u,
     PJ_CONTEXT *C=NULL;
     //projection parameters
     PJ *proyec=NULL;
+    //auxiliary variables for coordinate checking
+    double auxU=0.0,auxV=0.0;
     ////////////////////////////////////////////////////////////////////////////
     ////////////////////////////////////////////////////////////////////////////
     //error identifier
@@ -82,13 +84,22 @@ int proj_fwd(double* u,
     //check bad projection
     for(i=0;i<nElem;i++)
     {
-        //check for erroneous
-        if((u[i*incElem]==HUGE_VAL)||(!(INFINITY>u[i*incElem])))
+        auxU = u[i*incElem];
+        auxV = v[i*incElem];
+        //error checking
+        if((!isfinite(auxU))||(!isfinite(auxV))||
+           (auxU==HUGE_VAL)||(auxV==HUGE_VAL)||
+           (auxU==(-HUGE_VAL))||(auxV==(-HUGE_VAL)))
         {
-            //error position
-            *projectionError = (int)i;
-            //salimos del bucle
-            break;
+            //first occurrence
+            if((*projectionError)==-1)
+            {
+                //point position
+                *projectionError = (int)i;
+            }
+            //HUGE_VAL assign to output
+            u[i*incElem] = HUGE_VAL;
+            v[i*incElem] = HUGE_VAL;
         }
     }
     ////////////////////////////////////////////////////////////////////////////
@@ -123,6 +134,8 @@ int proj_inv(double* u,
     PJ *proyec=NULL;
     //projection information
     PJ_PROJ_INFO infop;
+    //auxiliary variables for coordinate checking
+    double auxU=0.0,auxV=0.0;
     ////////////////////////////////////////////////////////////////////////////
     ////////////////////////////////////////////////////////////////////////////
     //error identifier
@@ -181,13 +194,22 @@ int proj_inv(double* u,
     //check bad projection
     for(i=0;i<nElem;i++)
     {
-        //check for erroneous
-        if((u[i*incElem]==HUGE_VAL)||(!(INFINITY>u[i*incElem])))
+        auxU = u[i*incElem];
+        auxV = v[i*incElem];
+        //error checking
+        if((!isfinite(auxU))||(!isfinite(auxV))||
+           (auxU==HUGE_VAL)||(auxV==HUGE_VAL)||
+           (auxU==(-HUGE_VAL))||(auxV==(-HUGE_VAL)))
         {
-            //error position
-            *projectionError = (int)i;
-            //salimos del bucle
-            break;
+            //first occurrence
+            if((*projectionError)==-1)
+            {
+                //point position
+                *projectionError = (int)i;
+            }
+            //HUGE_VAL assign to output
+            u[i*incElem] = HUGE_VAL;
+            v[i*incElem] = HUGE_VAL;
         }
     }
     ////////////////////////////////////////////////////////////////////////////
@@ -223,7 +245,8 @@ int proj_transform(double* u,
     PJ_CONTEXT *C=NULL;
     //transformation parameters
     PJ *trans=NULL;
-    PJ *transOrdered=NULL;
+    //auxiliary variables for coordinate checking
+    double auxU=0.0,auxV=0.0;
     ////////////////////////////////////////////////////////////////////////////
     ////////////////////////////////////////////////////////////////////////////
     //error identifier
@@ -247,47 +270,44 @@ int proj_transform(double* u,
         //exit
         return idErr;
     }
-    //input coordinates must be ordered if EPSG codes are used (if not this call
-    //does not affect)
-    transOrdered = proj_normalize_for_visualization(C,trans);
-    //error checking
-    if(transOrdered==0)
-    {
-        //PROJ error code
-        idErr = proj_context_errno(C);
-        //memory free
-        proj_context_destroy(C);
-        proj_destroy(trans);
-        //error text
-        sprintf(errorText,"Error in calling "
-                          "'proj_normalize_for_visualization()'\n\t%s",
-                proj_errno_string(idErr));
-        //exit
-        return idErr;
-    }
-    //delete the old definition
-    proj_destroy(trans);
     ////////////////////////////////////////////////////////////////////////////
     ////////////////////////////////////////////////////////////////////////////
     //transformation
-    proj_trans_generic(transOrdered,PJ_FWD,u,ieb,nElem,v,ieb,nElem,z,ieb,nElem,
-                       t,ieb,nElem);
+    proj_trans_generic(trans,PJ_FWD,
+                       u,ieb,nElem,v,ieb,nElem,z,ieb,nElem,t,ieb,nElem);
     //check bad projection
     for(i=0;i<nElem;i++)
     {
-        //check for erroneous
-        if((u[i*incElem]==HUGE_VAL)||(!(INFINITY>u[i*incElem])))
+        auxU = u[i*incElem];
+        auxV = v[i*incElem];
+        //error checking
+        if((!isfinite(auxU))||(!isfinite(auxV))||
+           (auxU==HUGE_VAL)||(auxV==HUGE_VAL)||
+           (auxU==(-HUGE_VAL))||(auxV==(-HUGE_VAL)))
         {
-            //error position
-            *transformationError = (int)i;
-            //salimos del bucle
-            break;
+            //first occurrence
+            if((*transformationError)==-1)
+            {
+                //point position
+                *transformationError = (int)i;
+            }
+            //HUGE_VAL assign to output
+            u[i*incElem] = HUGE_VAL;
+            v[i*incElem] = HUGE_VAL;
+            if(z!=NULL)
+            {
+                z[i*incElem] = HUGE_VAL;
+            }
+            if(t!=NULL)
+            {
+                t[i*incElem] = HUGE_VAL;
+            }
         }
     }
     ////////////////////////////////////////////////////////////////////////////
     ////////////////////////////////////////////////////////////////////////////
     //memory free
-    proj_destroy(transOrdered);
+    proj_destroy(trans);
     proj_context_destroy(C);
     ////////////////////////////////////////////////////////////////////////////
     ////////////////////////////////////////////////////////////////////////////
